<?php

namespace Drupal\commerce_order_locking\EventSubscriber;

use Drupal\commerce_order_locking\Event\OrderWorkflowEvents;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Commerce order event subscriber.
 */
class OrderSubscriberLogAware implements EventSubscriberInterface {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\commerce_log\LogStorageInterface
   */
  protected $logStorage;

  /**
   * Constructs event subscriber.
   * @param EntityTypeManagerInterface $entity_type_manager
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->logStorage = $this->entityTypeManager->getStorage('commerce_log');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      OrderWorkflowEvents::ORDER_LOCK => ['onCommerceOrderLock'],
      OrderWorkflowEvents::ORDER_UNLOCK => ['onCommerceOrderUnlock'],
    ];
  }

  public function onCommerceOrderLock(WorkflowTransitionEvent $event) {
    $order = $event->getEntity();
    $this->logStorage->generate($order, 'commerce_order_locked', [
      'order_number' => $order->getOrderNumber(),
    ])->save();

  }

  public function onCommerceOrderUnlock(WorkflowTransitionEvent $event) {
    $order = $event->getEntity();
    $this->logStorage->generate($order, 'commerce_order_unlocked', [
      'order_number' => $order->getOrderNumber(),
    ])->save();
  }
}
